#
# spec file for package python-flit
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-flit
Version:        3.9.0
Release:        1.3
Summary:        Simplified packaging of Python modules
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/pypa/flit
Source:         https://files.pythonhosted.org/packages/source/f/flit/flit-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module flit-core >= %{version}}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module tomli-w}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-docutils
Requires:       python-flit-core >= %{version}
Requires:       python-requests
Requires:       python-tomli-w
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 2.7.3}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module testpath}
BuildRequires:  %{python_module tomli}
# /SECTION
%python_subpackages

%description
Simplified packaging of Python modules

%prep
%setup -q -n flit-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/flit
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand # create python name interpreter for test_find_python_excutable"
mkdir build/testbin
ln -s %{_bindir}/$python build/testbin/python
}
export PATH=$PWD/build/testbin/:$PATH
# test_invalid_classifier requires internet
# https://github.com/takluyver/flit/blob/96751efce651f8bae8ccb9e7f144dac460b3f013/flit/validate.py#L126
# "The error you get on a train, going through Oregon, without wifi"
%pytest -k "not (test_invalid_classifier or InstallTests)"

%post
%python_install_alternative flit

%postun
%python_uninstall_alternative flit

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/flit
%{python_sitelib}/flit
%{python_sitelib}/flit-%{version}*-info

%changelog
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 3.9.0:
  * New options :option:`flit build --use-vcs` and :option:`flit
    build --no-use-vcs` to enable & disable including all
    committed files in the sdist. For now --use-vcs is the
    default, but this is likely to change in a
    future version, to bring flit build in line with standard
    build frontends like python -m build
  * Sdist file names, and the name of the top-level folder in an
    sdist, are now normalised, in accordance with PEP 625
  * A statically defined version number can now be parsed from
    files called version.py, _version.py or __version__.py inside
    a packge, as well as from __init__.py, so executing code is
    required in fewer cases
  * Fix setting the flag for regular files in zip metadata
  * The timestamp embedded in the gzip wrapper for sdists now
    defaults to a fixed date, so building an sdist twice on the
    same machine should produce identical results, even without
    any special steps.
* Thu Aug 10 2023 Dirk Müller <dmueller@suse.com>
- skip install tests for better interoperability with PEP 668
* Wed May 10 2023 Johannes Kastl <kastl@b1-systems.de>
- Remove BuildRequire for PyYAML again. This was needed by the
  response package, which in the meantime got it.
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire PyYAML, see https://github.com/pypa/flit/issues/643
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Mar 10 2023 Dirk Müller <dmueller@suse.com>
- spec file cleanups
* Tue Nov  8 2022 Ben Greiner <code@bnavigator.de>
- Fix dependencies
* Tue Nov  8 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.8
  A project name containing hyphens is now automatically translated to use underscores for the import name (PR #566).
  New option flit install --only-deps to install the dependencies of the package, but not the package itself.
  Add support for recursive globbing (**) in sdist includes and excludes (PR #550).
  Python’s bytecode cache files (__pycache__ folders and .pyc files) are now always excluded from sdists (PR #581).
  Use tomllib in Python 3.11, rather than tomli (PR #573, PR #604).
  Fix crash when unable to get a password from keyring (PR #567).
  Fix including modified files in sdist when using Mercurial (PR #541).
  Fix for some cases of determining whether a package supports Python 2 or not (PR #593).
  Fix parsing version number from code using multiple assignments (PR #474).
  Document how to use a PyPI token with FLIT_PASSWORD (PR #602).
  Fix link to information about environment variables for pip (PR #576).
  Link to the docs for the latest stable version in package metadata (PR #589).
  Remove a mention of the toml package, which is no longer needed, from the Developing Flit page (PR #601).
  The bootstrap install script for flit_core accepts a new --install-root option.
  Ensure the license file is included in packages on PyPI (PR #603).
* Fri Mar 25 2022 Ben Greiner <code@bnavigator.de>
- Update to version 3.7.1
  * Support for external data files such as man pages or Jupyter
    extension support files (PR #510).
  * Project names are now lowercase in wheel filenames and
    .dist-info folder names, in line with the specifications (PR
    [#498]).
  * Improved support for bootstrapping a Python environment, e.g.
    for downstream packagers (PR #511). flit_core.wheel is usable
    with python -m to create wheels before the build tool is
    available, and flit_core sdists also include a script to
    install itself from a wheel before installer is available.
  * Use newer importlib APIs, fixing some deprecation warnings (PR
    [#499]).
  * Fix building packages which need execution to get the version
    number, and have a relative import in __init__.py (PR #531).
* Sun Jan  9 2022 Ben Greiner <code@bnavigator.de>
- Update to version 3.6
  * flit_core now bundles the tomli TOML parser library (version
    1.2.3) to avoid a circular dependency between flit_core and
    tomli (:ghpull:`492`). This means flit_core now has no
    dependencies except Python itself, both at build time and at
    runtime, simplifying :doc:`bootstrapping <bootstrap>`.
- The above is not fully applicale to openSUSE, we debundle.
- Release notes for Version 3.5.1
  * Fix development installs with flit install --symlink and
  - -pth-file, which were broken in 3.5.0, especially for packages
    using a src folder (:ghpull:`472`).
- Release notes for Version 3.5
  * You can now use Flit to distribute a module or package inside a
    namespace package (as defined by PEP 420). To do this, specify
    the import name of the concrete, inner module you are packaging
  - e.g. name = "sphinxcontrib.foo" - either in the [project]
    table, or under [tool.flit.module] if you want to use a
    different name on PyPI (:ghpull:`468`).
  * Flit no longer generates a setup.py file in sdists (.tar.gz
    packages) by default (:ghpull:`462`). Modern packaging tools
    don't need this. You can use the --setup-py flag to keep adding
    it for now, but this will probably be removed at some point in
    the future.
  * Fixed how flit init handles authors' names with non-ASCII
    characters (:ghpull:`460`).
  * When flit init generates a LICENSE file, the new pyproject.toml
    now references it (:ghpull:`467`).
* Fri Oct 15 2021 Ben Greiner <code@bnavigator.de>
- Update to version 3.4
  * Changelog since v1.3:
    https://flit.readthedocs.io/en/latest/history.html
- Remove upstreamed patches:
  - merged_pr_278.patch
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Sun May 19 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.3
